########################################################################
# Various project-standard color definitions.
#
# Intended to be imported (via "include") into other makefiles.
#
# These colors must match up with those from morbad-card-tools.css:
# Hmmm. It's tempting to filter that file at build-time with these.
.PHONY: colors
colors:
COLORS.MAKEFILE := $(word $(words $(MAKEFILE_LIST)),$(MAKEFILE_LIST))
#DV.D := $(dir $(realpath $(COLORS.MAKEFILE)))
DV.D := $(dir $(COLORS.MAKEFILE))

########################################################################
# Maintenance reminders:
#
# When adding new colors, the following things need to happen after
# updating this file:
#
# 1) Add new CSS classes to core.in.css: dv-fg-XYZ and dv-bg-XYZ.
#
# 1b) Run "make" from the project's top directory to re-generate
# core.css.
#
# 2) Update the method isColorName in morbad-card-tool.js.
#
# 3) Create glyphs for the new color. From the <glyphs> directory:
# 3a) mkdir NEW-COLOR-NAME
# 3b) cd black; make
#
# 4) Add dir <glyphs/NEW-COLOR-NAME> to the SCM.
########################################################################

color-list :=
define COLOR-DECL2
color-$(1) := $(2)
color-list += $(1)
endef
$(eval $(call COLOR-DECL2,lightblue,99e7ff))
$(eval $(call COLOR-DECL2,blue-dark,233f8f))
$(eval $(call COLOR-DECL2,green,c3d82d))
$(eval $(call COLOR-DECL2,green-dark,61b347))
$(eval $(call COLOR-DECL2,green-se,bce1ad))
$(eval $(call COLOR-DECL2,grey,dadada))
$(eval $(call COLOR-DECL2,magenta,f9139b))
$(eval $(call COLOR-DECL2,orange,fdbb41))
$(eval $(call COLOR-DECL2,purple,b146af))
$(eval $(call COLOR-DECL2,red,950b09))
$(eval $(call COLOR-DECL2,white,ffffff))
$(eval $(call COLOR-DECL2,yellow,ffef00))
$(eval $(call COLOR-DECL2,cream,fff2d8))

########################################################################
# Generates a list of -e 's/.../' expressions for replacing
# {{X}} with #$(color-X).
define COLOR-FILTERS-SED
$(foreach color,$(color-list),-e 's/{{$(color)}}/#$(color-$(color))/g')
endef
# $(info filters=$(call COLOR-FILTER-SED))
########################################################################
# Filter file $2 to $1, replacing tokens in the form {{colorname}}
# with their $(color-colorname) value.
define COLOR-FILTER-FILE
# $1 = input file
# $2 = output file
$(2): $(1) $$(COLORS.MAKEFILE)
	@echo "Creating $(2) ..."; \
	sed $(call COLOR-FILTERS-SED) < $(1) > $(2)
all: $(2)
#We're assuming the generated files are being stored in SCM (so that
#end users can use them), so do not include them in:
#CLEAN_FILES += $(2)
DISTCLEAN_FILES += $(2)
endef
#
########################################################################

#MORBAD.IN.CSS := $(DV.D)morbad-card-tools.in.css
#DV.CSS := $(subst .in.css,.css,$(MORBAD.IN.CSS))
#$(DV.CSS): $(MORBAD.IN.CSS) $(MAKEFILE_LIST)
#$(eval $(call COLOR-FILTER-FILE,$(MORBAD.IN.CSS),$(DV.CSS)))
colors: $(DV.CSS)

dv.css.in := $(DV.D)css/core.in.css \
    $(DV.D)css/common.in.css \
    $(DV.D)css/mini-cards.in.css \
    $(DV.D)css/standard-cards.in.css
dv.css.out := $(patsubst %.css.in,%.css,$(dv.css.in))
$(foreach css,$(dv.css.in),$(eval $(call COLOR-FILTER-FILE,$(css),$(patsubst %.in.css,%.css,$(css)))))
$(dv.css.out): $(MAKEFILE_LIST)
.PHONY: css
css: $(dv.css.out)
