-- This is the schema for Dark Venture card tool apps.
-- It requires a "recent" version of sqlite3 (probably something released
-- in 2017 or later).

PRAGMA foreign_keys=ON;
BEGIN TRANSACTION;

CREATE TABLE deck (
  uid TEXT PRIMARY KEY COLLATE NOCASE CHECK(uid = lower(uid)),
  -- cardtype:
  -- 1 = side quest ([very close to] mini-Euro size)
  -- 2 = heroic quest ("standard" size)
  cardtype INTEGER NOT NULL,
  name TEXT NOT NULL COLLATE NOCASE UNIQUE ON CONFLICT ABORT,
  rules TEXT DEFAULT NULL,
  mtime INTEGER NOT NULL,
  locked INTEGER NOT NULL DEFAULT 0,
  -- locked non-0 means:
  --  1) Deck itself should not be modifiable (e.g., no renaming).
  -- And possibly, but not [yet?] implemented...
  --   2) No more new cards should be allowed in this deck.
  --   3) All cards in the deck should be implicitly locked.
  -- All of those require app-side enforcement.
  UNIQUE(uid) ON CONFLICT ABORT
) WITHOUT ROWID;

INSERT INTO deck (mtime,cardtype,locked,name,uid) VALUES
(CAST(strftime('%s') as INTEGER), 1, 0, 'Fan-made Side Quests', 'sqf'),
(CAST(strftime('%s') as INTEGER), 2, 0, 'Fan-made Heroic Quests', 'hqf'),
(CAST(strftime('%s') as INTEGER), 1, 1, 'Example Side Quests', 'sqx'),
(CAST(strftime('%s') as INTEGER), 2, 1, 'Example Heroic Quests', 'hqx'),
(CAST(strftime('%s') as INTEGER), 1, 0, 'Scratchpad Side Quests', 'sqs'),
(CAST(strftime('%s') as INTEGER), 2, 0, 'Scratchpad Heroic Quests', 'hqs'),
(CAST(strftime('%s') as INTEGER), 1, 1, 'SQ: for testing only', 'sq-test'),
(CAST(strftime('%s') as INTEGER), 2, 1, 'HQ: for testing only', 'hq-test')
;

CREATE TABLE qcard (
  uid TEXT PRIMARY KEY, -- low-level card ID (random/UUID)
  cid TEXT NOT NULL COLLATE NOCASE CHECK(uid = lower(uid)), -- ID which appears on the card
  deck TEXT NOT NULL REFERENCES deck(uid) ON UPDATE CASCADE ON DELETE CASCADE CHECK(deck = lower(deck)),
  name TEXT NOT NULL COLLATE NOCASE,
  qp NOT NULL, -- quest points: integer or string
  contributor TEXT DEFAULT NULL,
  b_text TEXT NOT NULL,
  b_fontsize INTEGER NOT NULL DEFAULT 100,
  mtime INTEGER NOT NULL, -- DEFAULT current_timestamp,
  locked INTEGER NOT NULL DEFAULT 0,
  isofficial INTEGER NOT NULL DEFAULT 0,
  UNIQUE(deck,name) ON CONFLICT ABORT,
  UNIQUE(deck,cid) ON CONFLICT ABORT -- arguable and may cause grief when moving between decks.
) WITHOUT ROWID;

-- INSERT INTO qcard (uid,cid,deck,name,qp,contributor,b_text,b_fontsize,locked,mtime)
-- VALUES
-- ('x001','ex-01','SQX','Example',1,null,'Welcome to your quest!',100,1,CAST(strftime('%s') AS INTEGER)),
-- ('sqt-01','sqt-01','SQ-TEST','SQ Test 1',2,null,'Welcome to your quest!',100,1,CAST(strftime('%s') AS INTEGER))
-- ;

-- Intended only for an admin user.
CREATE TABLE user (
  name TEXT PRIMARY KEY NOT NULL COLLATE NOCASE,
  info TEXT DEFAULT NULL, -- email address or some such
  pw TEXT NOT NULL -- stored as hash of the user's password +
                   -- 'hash-secret' entry from config table.
) WITHOUT ROWID;

-- When logging in, we put an auth token in this table.
-- As long as the client keeps sending us this token
-- in a cookie, we'll keep updating the mtime field.
-- Logging out means removing the entry.
CREATE TABLE auth_token (
  user TEXT NOT NULL COLLATE NOCASE,
  mtime INTEGER NOT NULL,
  token TEXT NOT NULL,
  FOREIGN KEY(user) REFERENCES user(name) ON UPDATE CASCADE ON DELETE CASCADE  
);

CREATE TABLE config (
  k TEXT PRIMARY KEY NOT NULL,
  v TEXT DEFAULT NULL,
  UNIQUE(k) ON CONFLICT REPLACE
) WITHOUT ROWID;

INSERT INTO config (k,v) VALUES('hash-secret', LOWER(HEX(RANDOMBLOB(20))));

COMMIT;

-- select 'cleaning up...';
-- BEGIN;
-- COMMIT;
vacuum;
select 'done.';
