#!/bin/bash
########################################################################
# Startup script for s2cgi. Intended to be run as a CGI script under
# a fossil CGI/server.
#
# Before or (in most case) after sourcing s2cgi.lib.bash, this script
# may overwrite any configurable vars described in that file. The var
# S2_HOME is a notable exception: it must be set before sourcing
# s2cgi.lib.bash. In any case, all (re)configuration must take place
# before launching the CGI script by calling the runS2CGI shell
# function.
#export S2_CGI_IMPORT_ENV=1 # only enable this during debugging
########################################################################
# This script requires the s2cgi.lib.bash bootstrap script from the s2
# CGI framework:
#
#    https://fossil.wanderinghorse.net/r/s2cgi
#
# Place this script in that package's directory (or symlink it from
# here to there) and modify the paths below to suit the system.

for d in ~/s2 ~pi/s2 ~stephan/s2; do
    # ~stephan/s2 or ~pi/s2: my local machine, where CGIs run as an
    # apache user, not me.
    #
    # ~/s2: my hoster, where CGIs run as my account's user (the name
    # of which i do not want to publish in public code, thus we don't
    # use ~username/s2 here).
    if [[ -d "$d" ]]; then
        S2_HOME="$d"
        break
    fi
done

function exit500(){
    echo -en "Status: 500 Fatal bootstrapping error\r\n"
    echo -en "Content-Type: text/plain\r\n"
    echo -en "\r\n"
    echo "$@"
    exit 0
}

[[ -d "${S2_HOME}" ]] || exit500 "Configuration problem: cannot determine S2_HOME."

[[ -f "${FOSSIL_REPOSITORY}" ]] ||
    exit500 "Missing FOSSIL_REPOSITORY env var. " \
            "This script is intended to be run via fossil --extroot ..."

# exit500 "user=$(id -a) home=$(cd ~/ && pwd)"

########################################################################
# Configuration for the s2cgi bootstrap script...
S2_CGI_HOME="${S2_HOME}/cgi"
S2_CGI_RC_DIR="${S2_CGI_HOME}/cgi.d"
S2_CGI_ENABLE_SESSIONS=false
#DV_HOME="${S2_CGI_HOME}/dv.d"
DV_HOME="${DOCUMENT_ROOT}/.dv.d"
: ${S2_CGI_APP_SCRIPT="${DV_HOME}/dv-dispatch.s2"}
S2_CGI_RC_PATH=".:${DV_HOME}:${S2_CGI_RC_DIR}"

DV_DB="${DV_HOME}/db/dv.sqlite3"
DV_DB_LOG="${DV_HOME}/db/dv-log.sqlite3"
# export DV_DB DV_DB_LOG

. "${S2_CGI_HOME}"/s2cgi.lib.bash 2>/dev/null \
    || exit500 "Could not load s2cgi.lib.bash!"

[[ -d "${DV_HOME}" ]] || die 127 "DV_HOME dir not found."

runS2CGI --s2.require --cgi.sqlite3 \
         --dv.home="${DV_HOME}" \
         --dv.db="${DV_DB}" \
         --dv.log.db="${DV_DB_LOG}"
# does not return
